@@ -23,13 +23,14 @@ class Face:
         self.cz = 0
         self.nvertex=0
         self.blockIndex = 0 # not really needed except in periodicity 
+        self.id = 0
         
     def to_dict(self):
         """Returns a dictionary representaon of a face
         """
         return {'IMIN':min(self.I), 'JMIN':min(self.J), 'KMIN':min(self.K),
                     'IMAX':max(self.I), 'JMAX':max(self.J), 'KMAX':max(self.K),
-                    'id':0, 'block_index':self.blockIndex}
+                    'id':self.id, 'block_index':self.blockIndex}
 
     @property
     def centroid(self):
@@ -156,6 +157,9 @@ class Face:
 
     def set_block_index(self,val):
         self.blockIndex = val
+
+    def set_face_id(self,val):
+        self.id = val
         
     def normal(self,block):
         """Computes the normal vector of the face 
@@ -336,14 +340,14 @@ class Face:
                 maxIndx = indx
         return (self.x[minIndx],self.y[minIndx], self.z[minIndx]),(self.x[maxIndx],self.y[maxIndx], self.z[maxIndx])
     
-    def is_connected(self,f):
+    def is_connected(self,f,tol:float=1E-8):
         """Determines if face is connected by looking at the face centroid
 
         Args:
             f (Face): another face object 
         """
         val = np.sqrt((self.cx-f.cx)**2 + (self.cy-f.cy)**2 + (self.cz-f.cz)**2)
-        if val <1E-8:
+        if val <tol:
             return True
         else:
             return False
